@@ -1,5 +1,5 @@
 #ifndef __GCAL2TXT_H
-#  define __GCAL2TXT_H
+# define __GCAL2TXT_H
 /*
 *  gcal2txt.h:  Create a verbatim text file
 *               from a Gcal resource file header file.
@@ -15,15 +15,12 @@
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the `GNU General Public License' as published by
-*  the `Free Software Foundation'; either version 2, or (at your option)
+*  the `Free Software Foundation'; either version 3, or (at your option)
 *  any later version.
 *
 *  You should have received a copy of the `GNU General Public License'
 *  along with this program; if not, write to the:
 *
-*    Free Software Foundation, Inc.
-*    59 Temple Place - Suite 330
-*    Boston, MA 02111-1307,  USA
 */
 
 
@@ -37,9 +34,6 @@
 /*
 *  GLOBAL functions prototypes.
 */
-__BEGIN_DECLARATIONS
-EXPORT int
-main __P_((int   argc,
-           char *argv[]));
+__BEGIN_DECLARATIONS extern int main __P_ ((int argc, char *argv[]));
 __END_DECLARATIONS
 #endif /* __GCAL2TXT_H */
