@@ -1,10 +1,11 @@
 #ifndef __PRINT_H
-#  define __PRINT_H
+# define __PRINT_H
 /*
 *  print.h:  Create, construct and print the calendar sheet(s) header file.
 *
 *
 *  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
+*  Copyright (c) 2010 Free Software Foundation, Inc.
 *
 *  This software doesn't claim completeness, correctness or usability.
 *  On principle I will not be liable for ANY damages or losses (implicit
@@ -14,15 +15,12 @@
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the `GNU General Public License' as published by
-*  the `Free Software Foundation'; either version 2, or (at your option)
+*  the `Free Software Foundation'; either version 3, or (at your option)
 *  any later version.
 *
 *  You should have received a copy of the `GNU General Public License'
 *  along with this program; if not, write to the:
 *
-*    Free Software Foundation, Inc.
-*    59 Temple Place - Suite 330
-*    Boston, MA 02111-1307,  USA
 */
 
 
@@ -40,7 +38,6 @@ __BEGIN_DECLARATIONS
 /*
 ************************************************** Defined in `print.c'.
 */
-EXPORT void
-print_calendar __P_((void));
+extern void print_calendar __P_ ((void));
 __END_DECLARATIONS
 #endif /* __PRINT_H */
