@@ -1,5 +1,5 @@
 #ifndef __TCAL_H
-#  define __TCAL_H
+# define __TCAL_H
 /*
 *  tcal.h:  Start `gcal' with date set ONE day ahead header file.
 *
@@ -14,15 +14,12 @@
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the `GNU General Public License' as published by
-*  the `Free Software Foundation'; either version 2, or (at your option)
+*  the `Free Software Foundation'; either version 3, or (at your option)
 *  any later version.
 *
 *  You should have received a copy of the `GNU General Public License'
 *  along with this program; if not, write to the:
 *
-*    Free Software Foundation, Inc.
-*    59 Temple Place - Suite 330
-*    Boston, MA 02111-1307,  USA
 */
 
 
@@ -37,19 +34,16 @@
 *   Program specific preprocessor statements.
 */
 /* Name of environment variable for accessing the Gcal program. */
-#  define  ENV_VAR_GCALPROG     "GCALPROG"
+# define ENV_VAR_GCALPROG     "GCALPROG"
 
 /* Default shift value; may be set to "0"..."9". */
-#  define  SHIFT_VALUE_DEFAULT  "1"
+# define SHIFT_VALUE_DEFAULT  "1"
 
 
 
 /*
 *  GLOBAL functions prototypes.
 */
-__BEGIN_DECLARATIONS
-EXPORT int
-main __P_((int   argc,
-           char *argv[]));
+__BEGIN_DECLARATIONS extern int main __P_ ((int argc, char *argv[]));
 __END_DECLARATIONS
 #endif /* __TCAL_H */
